@@ -37,17 +37,11 @@ class Cache:
     def __setattr__(self, name: str, value: Any) -> None:
         setattr(self, name, value)
 
-    def __getattribute__(self, name: str) -> Any:
-        getattr(self, name)
-
-    
     def getobj(self, index: int) -> str | None:
-        if self.cachable:
-            return self.cache.get(index)
-        return None
+        return self.cache.get(index)
+        
 
     
     def setobj(self, value: str) -> str | None:
-        if self.cachable:
-            return self.cache.append(value)
-        return None
+        return self.cache.append(value)
+       
