@@ -22,8 +22,6 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-from ..client import Client
-
 __all__ = ("NotSafeForWork",)
 
 
@@ -39,8 +37,8 @@ class NotSafeForWork:
 
     TYPE = "nsfw"
 
-    def __init__(self, client: Client, /) -> None:
-        self.http = client()
+    def __init__(self, client: "Client", /) -> None:
+        self.http = client
 
     async def waifu(self) -> str:
 
@@ -90,5 +88,3 @@ class NotSafeForWork:
 
         return (await self.http.request(self.TYPE, "blowjob"))
 
-
-Nsfw = NotSafeForWork
