@@ -22,8 +22,6 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-from ..client import Client
-
 __all__ = ("SafeForWork",)
 
 
@@ -39,8 +37,8 @@ class SafeForWork:
 
     TYPE = "sfw"
     
-    def __init__(self, client: Client, /) -> None:
-        self.http = client()
+    def __init__(self, client: "Client", /) -> None:
+        self.http = client
 
     async def waifu(self) -> str:
 
@@ -413,5 +411,3 @@ class SafeForWork:
 
         return (await self.http.request(self.TYPE, "cringe"))
 
-
-Sfw = SafeForWork
